##  Error Log
On the Error Log tab of the Calculations page, you can view the history and details of failed calculation executions. Use the search field and apply filters to find the records you need.
**Tip**
You can monitor the status and last run time for each calculation on the calculations overview page. To view data changes triggered by calculations on a fact sheet, go to the Last update tab on the fact sheet page.
